@@ -3,6 +3,7 @@
 import asyncio
 import logging
 import os
+import re
 import subprocess
 from asyncio.exceptions import CancelledError
 from pathlib import Path
@@ -112,7 +113,7 @@ async def _detect_and_handle_text_plan(state_manager, agent_response, original_r
         else:
             response_text = str(agent_response)
 
-        if "TUNACODE_TASK_COMPLETE" in response_text:
+        if re.search(r"^\s*TUNACODE\s+DONE:\s*", response_text, re.IGNORECASE):
             await ui.warning(
                 "⚠️ Agent failed to call present_plan tool. Please provide clearer instructions."
             )
@@ -446,6 +447,9 @@ async def repl(state_manager: StateManager):
         await ui.success("Ready to assist")
         state_manager.session._startup_shown = True
 
+        # Offer tutorial to first-time users
+        await _offer_tutorial_if_appropriate(state_manager)
+
     instance = agent.get_or_create_agent(state_manager.session.current_model, state_manager)
 
     async with instance.run_mcp_servers():
@@ -539,3 +543,25 @@ async def repl(state_manager: StateManager):
             except (TypeError, ValueError):
                 pass
         await ui.info(MSG_SESSION_ENDED)
+
+
+async def _offer_tutorial_if_appropriate(state_manager: StateManager) -> None:
+    """Offer tutorial to first-time users if appropriate."""
+    try:
+        from tunacode.tutorial import TutorialManager
+
+        tutorial_manager = TutorialManager(state_manager)
+
+        # Check if we should offer tutorial
+        if await tutorial_manager.should_offer_tutorial():
+            # Offer tutorial to user
+            accepted = await tutorial_manager.offer_tutorial()
+            if accepted:
+                # Run tutorial
+                await tutorial_manager.run_tutorial()
+    except ImportError:
+        # Tutorial system not available, silently continue
+        pass
+    except Exception as e:
+        # Don't let tutorial errors crash the REPL
+        logger.warning(f"Tutorial offer failed: {e}")
