@@ -169,18 +169,21 @@ def get_or_create_agent(model: ModelName, state_manager: StateManager) -> Pydant
 
         # Add plan mode context if in plan mode
         if state_manager.is_plan_mode():
-            # REMOVE all TUNACODE_TASK_COMPLETE instructions from the system prompt
-            system_prompt = system_prompt.replace(
-                "TUNACODE_TASK_COMPLETE", "PLAN_MODE_TASK_PLACEHOLDER"
-            )
+            # REMOVE completion instructions from the system prompt in plan mode
+            for marker in ("TUNACODE_TASK_COMPLETE", "TUNACODE DONE:"):
+                system_prompt = system_prompt.replace(marker, "PLAN_MODE_TASK_PLACEHOLDER")
             # Remove the completion guidance that conflicts with plan mode
             lines_to_remove = [
+                "When a task is COMPLETE, start your response with: TUNACODE DONE:",
+                "4. When a task is COMPLETE, start your response with: TUNACODE DONE:",
                 "When a task is COMPLETE, start your response with: TUNACODE_TASK_COMPLETE",
                 "4. When a task is COMPLETE, start your response with: TUNACODE_TASK_COMPLETE",
                 "**How to signal completion:**",
                 "TUNACODE_TASK_COMPLETE",
+                "TUNACODE DONE:",
                 "[Your summary of what was accomplished]",
                 "**IMPORTANT**: Always evaluate if you've completed the task. If yes, use TUNACODE_TASK_COMPLETE.",
+                "**IMPORTANT**: Always evaluate if you've completed the task. If yes, use TUNACODE DONE:",
                 "This prevents wasting iterations and API calls.",
             ]
             for line in lines_to_remove:
@@ -240,29 +243,34 @@ YOU MUST EXECUTE present_plan TOOL TO COMPLETE ANY PLANNING TASK.
         except Exception as e:
             logger.warning(f"Warning: Failed to load todos: {e}")
 
+        # Get tool strict validation setting from config (default to False for backward compatibility)
+        tool_strict_validation = state_manager.session.user_config.get("settings", {}).get(
+            "tool_strict_validation", False
+        )
+
         # Create tool list based on mode
         if state_manager.is_plan_mode():
             # Plan mode: Only read-only tools + present_plan
             tools_list = [
-                Tool(present_plan, max_retries=max_retries),
-                Tool(glob, max_retries=max_retries),
-                Tool(grep, max_retries=max_retries),
-                Tool(list_dir, max_retries=max_retries),
-                Tool(read_file, max_retries=max_retries),
+                Tool(present_plan, max_retries=max_retries, strict=tool_strict_validation),
+                Tool(glob, max_retries=max_retries, strict=tool_strict_validation),
+                Tool(grep, max_retries=max_retries, strict=tool_strict_validation),
+                Tool(list_dir, max_retries=max_retries, strict=tool_strict_validation),
+                Tool(read_file, max_retries=max_retries, strict=tool_strict_validation),
             ]
         else:
             # Normal mode: All tools
             tools_list = [
-                Tool(bash, max_retries=max_retries),
-                Tool(present_plan, max_retries=max_retries),
-                Tool(glob, max_retries=max_retries),
-                Tool(grep, max_retries=max_retries),
-                Tool(list_dir, max_retries=max_retries),
-                Tool(read_file, max_retries=max_retries),
-                Tool(run_command, max_retries=max_retries),
-                Tool(todo_tool._execute, max_retries=max_retries),
-                Tool(update_file, max_retries=max_retries),
-                Tool(write_file, max_retries=max_retries),
+                Tool(bash, max_retries=max_retries, strict=tool_strict_validation),
+                Tool(present_plan, max_retries=max_retries, strict=tool_strict_validation),
+                Tool(glob, max_retries=max_retries, strict=tool_strict_validation),
+                Tool(grep, max_retries=max_retries, strict=tool_strict_validation),
+                Tool(list_dir, max_retries=max_retries, strict=tool_strict_validation),
+                Tool(read_file, max_retries=max_retries, strict=tool_strict_validation),
+                Tool(run_command, max_retries=max_retries, strict=tool_strict_validation),
+                Tool(todo_tool._execute, max_retries=max_retries, strict=tool_strict_validation),
+                Tool(update_file, max_retries=max_retries, strict=tool_strict_validation),
+                Tool(write_file, max_retries=max_retries, strict=tool_strict_validation),
             ]
 
         # Log which tools are being registered
@@ -291,6 +299,11 @@ YOU MUST EXECUTE present_plan TOOL TO COMPLETE ANY PLANNING TASK.
             (
                 state_manager.is_plan_mode(),
                 str(state_manager.session.user_config.get("settings", {}).get("max_retries", 3)),
+                str(
+                    state_manager.session.user_config.get("settings", {}).get(
+                        "tool_strict_validation", False
+                    )
+                ),
                 str(state_manager.session.user_config.get("mcpServers", {})),
             )
         )
