@@ -1,5 +1,6 @@
 """Task completion detection utilities."""
 
+import re
 from typing import Tuple
 
 
@@ -18,11 +19,14 @@ def check_task_completion(content: str) -> Tuple[bool, str]:
     if not content:
         return False, content
 
-    lines = content.strip().split("\n")
-    if lines and lines[0].strip() == "TUNACODE_TASK_COMPLETE":
-        # Task is complete, return cleaned content
-        cleaned_lines = lines[1:] if len(lines) > 1 else []
-        cleaned_content = "\n".join(cleaned_lines).strip()
-        return True, cleaned_content
+    lines = content.split("\n")
+
+    # New marker: any line starting with "TUNACODE DONE:" (case-insensitive, allow leading whitespace)
+    done_pattern = re.compile(r"^\s*TUNACODE\s+DONE:\s*", re.IGNORECASE)
+    for idx, line in enumerate(lines):
+        if done_pattern.match(line):
+            # Remove the marker line and return remaining content
+            cleaned = "\n".join(lines[:idx] + lines[idx + 1 :]).strip()
+            return True, cleaned
 
     return False, content
