@@ -37,8 +37,12 @@ class GitSafetySetup(BaseSetup):
         # Always run unless user has explicitly disabled it
         return not self.state_manager.session.user_config.get("skip_git_safety", False)
 
-    async def execute(self, _force: bool = False) -> None:
+    async def execute(self, _force: bool = False, wizard_mode: bool = False) -> None:
         """Create a safety branch for TunaCode operations."""
+        # Skip git safety during wizard mode to avoid UI interference
+        if wizard_mode:
+            return
+
         try:
             # Check if git is installed
             result = subprocess.run(
