@@ -2,6 +2,8 @@
 
 State management system for session data in TunaCode CLI.
 Handles user preferences, conversation history, and runtime state.
+
+CLAUDE_ANCHOR[state-module]: Central state management and session tracking
 """
 
 import uuid
@@ -13,6 +15,8 @@ from tunacode.types import (
     InputSessions,
     MessageHistory,
     ModelName,
+    PlanDoc,
+    PlanPhase,
     SessionId,
     TodoItem,
     ToolName,
@@ -27,6 +31,8 @@ if TYPE_CHECKING:
 
 @dataclass
 class SessionState:
+    """CLAUDE_ANCHOR[session-state]: Core session state container"""
+
     user_config: UserConfig = field(default_factory=dict)
     agents: dict[str, Any] = field(
         default_factory=dict
@@ -44,9 +50,7 @@ class SessionState:
     input_sessions: InputSessions = field(default_factory=dict)
     current_task: Optional[Any] = None
     todos: list[TodoItem] = field(default_factory=list)
-    # ESC key tracking for double-press functionality
-    esc_press_count: int = 0
-    last_esc_time: Optional[float] = None
+    # Operation state tracking
     operation_cancelled: bool = False
     # Enhanced tracking for thoughts display
     files_in_context: set[str] = field(default_factory=set)
@@ -83,6 +87,12 @@ class SessionState:
     iteration_budgets: dict[str, int] = field(default_factory=dict)
     recursive_context_stack: list[dict[str, Any]] = field(default_factory=list)
 
+    # Plan Mode state tracking
+    plan_mode: bool = False
+    plan_phase: Optional[PlanPhase] = None
+    current_plan: Optional[PlanDoc] = None
+    plan_approved: bool = False
+
     def update_token_count(self):
         """Calculates the total token count from messages and files in context."""
         message_contents = [get_message_content(msg) for msg in self.messages]
@@ -92,6 +102,8 @@ class SessionState:
 
 
 class StateManager:
+    """CLAUDE_ANCHOR[state-manager]: Main state manager singleton"""
+
     def __init__(self):
         self._session = SessionState()
         self._tool_handler: Optional["ToolHandler"] = None
@@ -163,3 +175,39 @@ class StateManager:
     def reset_session(self) -> None:
         """Reset the session to a fresh state."""
         self._session = SessionState()
+
+    # Plan Mode methods
+    def enter_plan_mode(self) -> None:
+        """Enter plan mode - restricts to read-only operations."""
+        self._session.plan_mode = True
+        self._session.plan_phase = PlanPhase.PLANNING_RESEARCH
+        self._session.current_plan = None
+        self._session.plan_approved = False
+        # Clear agent cache to force recreation with plan mode tools
+        self._session.agents.clear()
+
+    def exit_plan_mode(self, plan: Optional[PlanDoc] = None) -> None:
+        """Exit plan mode with optional plan data."""
+        self._session.plan_mode = False
+        self._session.plan_phase = None
+        self._session.current_plan = plan
+        self._session.plan_approved = False
+        # Clear agent cache to force recreation without plan mode tools
+        self._session.agents.clear()
+
+    def approve_plan(self) -> None:
+        """Mark current plan as approved for execution."""
+        self._session.plan_approved = True
+        self._session.plan_mode = False
+
+    def is_plan_mode(self) -> bool:
+        """Check if currently in plan mode."""
+        return self._session.plan_mode
+
+    def set_current_plan(self, plan: PlanDoc) -> None:
+        """Set the current plan data."""
+        self._session.current_plan = plan
+
+    def get_current_plan(self) -> Optional[PlanDoc]:
+        """Get the current plan data."""
+        return self._session.current_plan
