@@ -18,7 +18,9 @@ from tunacode.core.setup import (
 from tunacode.core.state import StateManager
 
 
-async def setup(run_setup: bool, state_manager: StateManager, cli_config: dict = None) -> None:
+async def setup(
+    run_setup: bool, state_manager: StateManager, cli_config: dict = None, wizard_mode: bool = False
+) -> None:
     """
     Setup TunaCode on startup using the new setup coordinator.
 
@@ -26,6 +28,7 @@ async def setup(run_setup: bool, state_manager: StateManager, cli_config: dict =
         run_setup (bool): If True, force run the setup process, resetting current config.
         state_manager (StateManager): The state manager instance.
         cli_config (dict): Optional CLI configuration with baseurl, model, and key.
+        wizard_mode (bool): If True, run interactive setup wizard.
     """
     coordinator = SetupCoordinator(state_manager)
 
@@ -39,7 +42,7 @@ async def setup(run_setup: bool, state_manager: StateManager, cli_config: dict =
     coordinator.register_step(GitSafetySetup(state_manager))
 
     # Run all setup steps
-    await coordinator.run_setup(force_setup=run_setup)
+    await coordinator.run_setup(force_setup=run_setup, wizard_mode=wizard_mode)
 
 
 async def setup_agent(agent: Optional[Any], state_manager: StateManager) -> None:
