@@ -1,5 +1,7 @@
 """Panel display functions for TunaCode UI."""
 
+import asyncio
+import time
 from typing import Any, Optional, Union
 
 from rich.box import ROUNDED
@@ -81,11 +83,24 @@ async def agent(text: str, bottom: int = 1) -> None:
 class StreamingAgentPanel:
     """Streaming agent panel using Rich.Live for progressive display."""
 
+    bottom: int
+    title: str
+    content: str
+    live: Optional[Live]
+    _last_update_time: float
+    _dots_task: Optional[asyncio.Task]
+    _dots_count: int
+    _show_dots: bool
+
     def __init__(self, bottom: int = 1):
         self.bottom = bottom
         self.title = f"[bold {colors.primary}]●[/bold {colors.primary}] {APP_NAME}"
         self.content = ""
         self.live = None
+        self._last_update_time = 0.0
+        self._dots_task = None
+        self._dots_count = 0
+        self._show_dots = True  # Start with dots enabled for "Thinking..."
 
     def _create_panel(self) -> Padding:
         """Create a Rich panel with current content."""
@@ -94,11 +109,27 @@ class StreamingAgentPanel:
 
         from tunacode.constants import UI_THINKING_MESSAGE
 
-        # Handle the default thinking message with Rich markup
+        # Show "Thinking..." only when no content has arrived yet
         if not self.content:
-            content_renderable: Union[Text, Markdown] = Text.from_markup(UI_THINKING_MESSAGE)
+            # Apply dots animation to "Thinking..." message too
+            thinking_msg = UI_THINKING_MESSAGE
+            if self._show_dots:
+                # Remove the existing ... from the message and add animated dots
+                base_msg = thinking_msg.replace("...", "")
+                dots_patterns = ["", ".", "..", "..."]
+                dots = dots_patterns[self._dots_count % len(dots_patterns)]
+                thinking_msg = base_msg + dots
+            content_renderable: Union[Text, Markdown] = Text.from_markup(thinking_msg)
         else:
-            content_renderable = Markdown(self.content)
+            # Once we have content, show it with optional dots animation
+            display_content = self.content
+            # Add animated dots if we're waiting for more content
+            if self._show_dots:
+                # Cycle through: "", ".", "..", "..."
+                dots_patterns = ["", ".", "..", "..."]
+                dots = dots_patterns[self._dots_count % len(dots_patterns)]
+                display_content = self.content.rstrip() + dots
+            content_renderable = Markdown(display_content)
         panel_obj = Panel(
             Padding(content_renderable, (0, 1, 0, 1)),
             title=f"[bold]{self.title}[/bold]",
@@ -117,31 +148,99 @@ class StreamingAgentPanel:
             ),
         )
 
+    async def _animate_dots(self):
+        """Animate dots after a pause in streaming."""
+        while True:
+            await asyncio.sleep(0.2)  # Faster animation cycle
+            current_time = time.time()
+            # Use shorter delay for initial "Thinking..." phase
+            delay_threshold = 0.3 if not self.content else 1.0
+            # Show dots after the delay threshold
+            if current_time - self._last_update_time > delay_threshold:
+                self._show_dots = True
+                self._dots_count += 1
+                if self.live:
+                    self.live.update(self._create_panel())
+            else:
+                # Only reset if we have content (keep dots for initial "Thinking...")
+                if self.content:
+                    self._show_dots = False
+                    self._dots_count = 0
+
     async def start(self):
         """Start the live streaming display."""
         from .output import console
 
         self.live = Live(self._create_panel(), console=console, refresh_per_second=4)
         self.live.start()
+        # For "Thinking...", set time in past to trigger dots immediately
+        if not self.content:
+            self._last_update_time = time.time() - 0.4  # Triggers dots on first cycle
+        else:
+            self._last_update_time = time.time()
+        # Start the dots animation task
+        self._dots_task = asyncio.create_task(self._animate_dots())
 
     async def update(self, content_chunk: str):
         """Update the streaming display with new content."""
         # Defensive: some providers may yield None chunks intermittently
         if content_chunk is None:
             content_chunk = ""
+
+        # Filter out plan mode system prompts and tool definitions from streaming
+        if any(
+            phrase in str(content_chunk)
+            for phrase in [
+                "🔧 PLAN MODE",
+                "TOOL EXECUTION ONLY",
+                "planning assistant that ONLY communicates",
+                "namespace functions {",
+                "namespace multi_tool_use {",
+                "You are trained on data up to",
+            ]
+        ):
+            return
+
         # Ensure type safety for concatenation
         self.content = (self.content or "") + str(content_chunk)
+
+        # Reset the update timer when we get new content
+        self._last_update_time = time.time()
+        self._show_dots = False  # Hide dots immediately when new content arrives
+
         if self.live:
             self.live.update(self._create_panel())
 
     async def set_content(self, content: str):
         """Set the complete content (overwrites previous)."""
+        # Filter out plan mode system prompts and tool definitions
+        if any(
+            phrase in str(content)
+            for phrase in [
+                "🔧 PLAN MODE",
+                "TOOL EXECUTION ONLY",
+                "planning assistant that ONLY communicates",
+                "namespace functions {",
+                "namespace multi_tool_use {",
+                "You are trained on data up to",
+            ]
+        ):
+            return
+
         self.content = content
         if self.live:
             self.live.update(self._create_panel())
 
     async def stop(self):
         """Stop the live streaming display."""
+        # Cancel the dots animation task
+        if self._dots_task:
+            self._dots_task.cancel()
+            try:
+                await self._dots_task
+            except asyncio.CancelledError:
+                pass
+
         if self.live:
             # Get the console before stopping the live display
             from .output import console
